==> billogram-foundation-3.13.10.tgz: package/modules/components/component/redux/createComponentsReducerProvider.js <==
import { handleActions } from 'redux-seamless-reducers';
import reduceReducers from 'reduce-reducers';
import Immutable from 'seamless-immutable';

import { reducer as mount } from './mount';
import { reducer as unmount } from './unmount';

import { reducer as checkboxChange } from '../../checkbox/redux/checkboxChange';

import { reducer as datepickerChange } from '../../datepicker/redux/datepickerChange';
import { reducer as datepickerCollapse } from '../../datepicker/redux/datepickerCollapse';
import { reducer as datepickerExpand } from '../../datepicker/redux/datepickerExpand';
import { reducer as datepickerSelectedIndexChange } from '../../datepicker/redux/datepickerSelectedIndexChange';

import { reducer as dropdownChange } from '../../dropdown/redux/dropdownChange';
import { reducer as dropdownCollapse } from '../../dropdown/redux/dropdownCollapse';
import { reducer as dropdownExpand } from '../../dropdown/redux/dropdownExpand';
import { reducer as dropdownHighlightedIndexChange } from '../../dropdown/redux/dropdownHighlightedIndexChange';

import { reducer as monthpickerChange } from '../../monthpicker/redux/monthpickerChange';

import { reducer as radioButtonGroupChange } from '../../radio/redux/radioButtonGroupChange';

import { reducer as textareaChange } from '../../textarea/redux/textareaChange';
import { reducer as textboxChange } from '../../textbox/redux/textboxChange';


export default (registry) => ({
    actionObject = {},
    defaultState = {},
    reducers = []
} = {}) => {
    const meta = defaultState.meta;
    // alas, seamless-immutable doesn't support using Set.
    const initialState = { ...defaultState, meta: { ...meta, mounted: {} } };

    const handler = handleActions({
        ...mount,
        ...unmount,
        ...actionObject
    });

    return {
        components: (state = Immutable(initialState), action) => {
            return reduceReducers(
                checkboxChange,

                datepickerChange,
                datepickerCollapse,
                datepickerExpand,
                datepickerSelectedIndexChange,

                dropdownChange,
                dropdownCollapse,
                dropdownExpand,
                dropdownHighlightedIndexChange,

                monthpickerChange,

                radioButtonGroupChange,

                textareaChange,

                textboxChange,

                handler,
                ...reducers,

                ...registry.getReducers()
            )(state, action);
        }
    };
};

==> billogram-foundation-4.0.0.tgz: package/modules/components/component/redux/createComponentsReducerProvider.js <==
import { handleActions } from 'redux-seamless-reducers';
import reduceReducers from 'reduce-reducers';
import Immutable from 'seamless-immutable';

import { reducer as mount } from './mount';
import { reducer as unmount } from './unmount';

import { reducer as checkboxChange } from '../../checkbox/redux/checkboxChange';
import { reducer as datepickerChange } from '../../datepicker/redux/datepickerChange';
import { reducer as dropdownChange } from '../../dropdown/redux/dropdownChange';
import { reducer as monthpickerChange } from '../../monthpicker/redux/monthpickerChange';
import { reducer as radioButtonGroupChange } from '../../radio/redux/radioButtonGroupChange';
import { reducer as switchChange } from '../../switch/redux/switchChange';
import { reducer as textareaChange } from '../../textarea/redux/textareaChange';
import { reducer as textboxChange } from '../../textbox/redux/textboxChange';


export default (registry) => ({
    actionObject = {},
    defaultState = {},
    reducers = []
} = {}) => {
    const meta = defaultState.meta;
    // alas, seamless-immutable doesn't support using Set.
    const initialState = { ...defaultState, meta: { ...meta, mounted: {} } };

    const handler = handleActions({
        ...mount,
        ...unmount,
        ...actionObject
    });

    return {
        components: (state = Immutable(initialState), action) => {
            return reduceReducers(
                checkboxChange,
                datepickerChange,
                dropdownChange,
                monthpickerChange,
                radioButtonGroupChange,
                switchChange,
                textareaChange,
                textboxChange,
                handler,
                ...reducers,
                ...registry.getReducers()
            )(state, action);
        }
    };
};
